@@ -86,10 +86,14 @@ from .mesh import (
     Grid,
 )
 from .constitution import (
+    UserMaterial,
+    UserMaterialStrain,
     NeoHooke,
+    OgdenRoxburgh,
     LinearElastic,
     LinearElasticPlaneStress,
     LinearElasticPlaneStrain,
+    LinearElasticPlasticIsotropicHardening,
     ThreeFieldVariation,
     LineChange,
     AreaChange,
@@ -106,7 +110,6 @@ from .mechanics import (
     SolidBodyNearlyIncompressible,
     StateNearlyIncompressible,
     SolidBodyPressure,
-    SolidBodyTensor,
     SolidBodyGravity,
     PointLoad,
     Step,
